==> spd-model-2.0.0-20130523.135248-23-sources.jar: org/gcube/data/spd/model/products/OccurrencePoint.java <==
package org.gcube.data.spd.model.products;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.data.spd.model.BasisOfRecord;
import org.gcube.data.spd.model.util.ElementProperty;


@XmlRootElement
@XmlAccessorType(XmlAccessType.NONE)
public class OccurrencePoint implements ResultElement{
		
	@XmlAttribute(required=true)
	private String id;
	@XmlAttribute(required=true)
	private String provider;
	@XmlAttribute(required=true)
	private String author;
	@XmlAttribute(required=true)
	private String credits;
	@XmlAttribute(required=true)
	private String institutionCode;
	@XmlAttribute(required=true)
	private String collectionCode;
	@XmlAttribute(required=true)
	private String catalogueNumber;
	@XmlAttribute(required=true)
	private String recordedBy;
	@XmlAttribute(required=true)
	private Calendar eventDate;
	@XmlAttribute
	private Calendar modified;
	@XmlAttribute(required=true)
	private String scientificName;
	@XmlAttribute
	private String kingdom;
	@XmlAttribute
	private String family;
	@XmlAttribute(required=true)
	private String locality;
	@XmlAttribute
	private String country;
	@XmlAttribute
	private String citation;
	@XmlAttribute(required=true)
	private double decimalLatitude;
	@XmlAttribute(required=true)
	private double decimalLongitude;
	@XmlAttribute
	private String coordinateUncertaintyInMeters;
	@XmlAttribute
	private double maxDepth;
	@XmlAttribute
	private double minDepth;
	@XmlAttribute(required=true)
	private BasisOfRecord basisOfRecord;
	
	@XmlElement(required=true, nillable=false)
	private DataSet dataSet;
	
	@XmlElement(required=true)
	private List<ElementProperty> properties = new ArrayList<ElementProperty>() ;
	
	
	protected OccurrencePoint(){}
		
	public OccurrencePoint(String id) {
		super();
		this.id = id;
		this.basisOfRecord = BasisOfRecord.HumanObservation;
	}
	
	public String getId() {
		return id;
	}
	public void setId(String id) {
		this.id = id;
	}
	public String getCitation() {
		return citation;
	}
	public void setCitation(String citation) {
		this.citation = citation;
	}
	public String getCountry() {
		return country;
	}
	public void setCountry(String country) {
		this.country = country;
	}
	public String getInstitutionCode() {
		return institutionCode;
	}
	public void setInstitutionCode(String institutionCode) {
		this.institutionCode = institutionCode;
	}
	public String getCollectionCode() {
		return collectionCode;
	}
	public void setCollectionCode(String collectionCode) {
		this.collectionCode = collectionCode;
	}
	public String getRecordedBy() {
		return recordedBy;
	}
	public void setRecordedBy(String recordedBy) {
		this.recordedBy = recordedBy;
	}
	public Calendar getEventDate() {
		return eventDate;
	}
	public void setEventDate(Calendar eventDate) {
		this.eventDate = eventDate;
	}
	public String getScientificName() {
		return scientificName;
	}
	public void setScientificName(String scientificName) {
		this.scientificName = scientificName;
	}
	public String getKingdom() {
		return kingdom;
	}
	public void setKingdom(String kingdom) {
		this.kingdom = kingdom;
	}
	public String getFamily() {
		return family;
	}
	public void setFamily(String family) {
		this.family = family;
	}
	public String getLocality() {
		return locality;
	}
	public void setLocality(String locality) {
		this.locality = locality;
	}
	public double getDecimalLatitude() {
		return decimalLatitude;
	}
	public void setDecimalLatitude(double decimalLatitude) {
		this.decimalLatitude = decimalLatitude;
	}
	public double getDecimalLongitude() {
		return decimalLongitude;
	}
	public void setDecimalLongitude(double decimalLongitude) {
		this.decimalLongitude = decimalLongitude;
	}
	public String getCoordinateUncertaintyInMeters() {
		return coordinateUncertaintyInMeters;
	}
	public void setCoordinateUncertaintyInMeters(String coordinateUncertaintyInMeters) {
		this.coordinateUncertaintyInMeters = coordinateUncertaintyInMeters;
	}
	public BasisOfRecord getBasisOfRecord() {
		return basisOfRecord;
	}
	public void setBasisOfRecord(BasisOfRecord basisOfRecord) {
		this.basisOfRecord = basisOfRecord;
	}
	public double getMaxDepth() {
		return maxDepth;
	}
	public void setMaxDepth(double maxDepth) {
		this.maxDepth = maxDepth;
	}
	public double getMinDepth() {
		return minDepth;
	}
	public void setMinDepth(double minDepth) {
		this.minDepth = minDepth;
	}
	
	public Calendar getModified() {
		return modified;
	}
	public void setModified(Calendar modified) {
		this.modified = modified;
	}
	
	public String getCatalogueNumber() {
		return catalogueNumber;
	}
	public void setCatalogueNumber(String catalogueNumber) {
		this.catalogueNumber = catalogueNumber;
	}
	
	public DataSet getDataSet() {
		return dataSet;
	}
	public void setDataSet(DataSet dataSet) {
		this.dataSet = dataSet;
	}
	
	
	
	public String getProvider() {
		return provider;
	}

	public void setProvider(String provider) {
		this.provider = provider;
	}

	public ProductsType getType() {
		return ProductsType.OCCURRENCEPOINT;
	}

	
	
	public String getAuthor() {
		return author;
	}

	public void setAuthor(String author) {
		this.author = author;
	}

	public String getCredits() {
		return credits;
	}

	public void setCredits(String credits) {
		this.credits = credits;
	}

	public void addProperty(ElementProperty property){
		this.properties.add(property);
	}
	
	public void resetProperties(){
		this.properties = new ArrayList<ElementProperty>();
	}
	
	
	public List<ElementProperty> getProperties() {
		return Collections.unmodifiableList(properties);
	}

	@Override
	public String toString() {
		return "OccurrencePoint [id=" + id + ", institutionCode="
				+ institutionCode + ", collectionCode=" + collectionCode
				+ ", catalogueNumber=" + catalogueNumber + ", recordedBy="
				+ recordedBy + ", eventDate=" + eventDate + ", modified="
				+ modified + ", scientificName=" + scientificName
				+ ", kingdom=" + kingdom + ", family=" + family + ", locality="
				+ locality + ", country=" + country + ", citation=" + citation
				+ ", decimalLatitude=" + decimalLatitude
				+ ", decimalLongitude=" + decimalLongitude
				+ ", coordinateUncertaintyInMeters="
				+ coordinateUncertaintyInMeters + ", maxDepth=" + maxDepth
				+ ", minDepth=" + minDepth + ", basisOfRecord=" + basisOfRecord
				+ ", dataSet=" + dataSet + "]";
	}

	
}

==> spd-model-2.1.0-20131118.213724-97-sources.jar: org/gcube/data/spd/model/products/OccurrencePoint.java <==
package org.gcube.data.spd.model.products;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.data.spd.model.BasisOfRecord;
import org.gcube.data.spd.model.util.ElementProperty;


@XmlRootElement
@XmlAccessorType(XmlAccessType.NONE)
public class OccurrencePoint implements ResultElement{
		
	@XmlAttribute(required=true)
	private String id;
	@XmlAttribute(required=true)
	private String provider;
	@XmlAttribute(required=true)
	private String author;
	@XmlAttribute(required=true)
	private String credits;
	@XmlAttribute(required=true)
	private String institutionCode;
	@XmlAttribute(required=true)
	private String collectionCode;
	@XmlAttribute(required=true)
	private String catalogueNumber;
	@XmlAttribute(required=true)
	private String recordedBy;
	@XmlAttribute(required=true)
	private Calendar eventDate;
	@XmlAttribute
	private Calendar modified;
	@XmlAttribute(required=true)
	private String scientificName;
	@XmlAttribute
	private String kingdom;
	@XmlAttribute
	private String family;
	@XmlAttribute(required=true)
	private String locality;
	@XmlAttribute
	private String country;
	@XmlAttribute
	private String citation;
	@XmlAttribute(required=true)
	private double decimalLatitude;
	@XmlAttribute(required=true)
	private double decimalLongitude;
	@XmlAttribute
	private String coordinateUncertaintyInMeters;
	@XmlAttribute
	private double maxDepth;
	@XmlAttribute
	private double minDepth;
	@XmlAttribute(required=true)
	private BasisOfRecord basisOfRecord;
	
	@XmlElement(required=true, nillable=false)
	private DataSet dataSet;
	
	@XmlElement(required=true)
	private List<ElementProperty> properties = new ArrayList<ElementProperty>() ;
	
	
	protected OccurrencePoint(){}
		
	public OccurrencePoint(String id) {
		super();
		this.id = id;
		this.basisOfRecord = BasisOfRecord.HumanObservation;
	}
	
	public String getId() {
		return id;
	}
	public void setId(String id) {
		this.id = id;
	}
	public String getCitation() {
		return citation;
	}
	public void setCitation(String citation) {
		this.citation = citation;
	}
	public String getCountry() {
		return country;
	}
	public void setCountry(String country) {
		this.country = country;
	}
	public String getInstitutionCode() {
		return institutionCode;
	}
	public void setInstitutionCode(String institutionCode) {
		this.institutionCode = institutionCode;
	}
	public String getCollectionCode() {
		return collectionCode;
	}
	public void setCollectionCode(String collectionCode) {
		this.collectionCode = collectionCode;
	}
	public String getRecordedBy() {
		return recordedBy;
	}
	public void setRecordedBy(String recordedBy) {
		this.recordedBy = recordedBy;
	}
	public Calendar getEventDate() {
		return eventDate;
	}
	public void setEventDate(Calendar eventDate) {
		this.eventDate = eventDate;
	}
	public String getScientificName() {
		return scientificName;
	}
	public void setScientificName(String scientificName) {
		this.scientificName = scientificName;
	}
	public String getKingdom() {
		return kingdom;
	}
	public void setKingdom(String kingdom) {
		this.kingdom = kingdom;
	}
	public String getFamily() {
		return family;
	}
	public void setFamily(String family) {
		this.family = family;
	}
	public String getLocality() {
		return locality;
	}
	public void setLocality(String locality) {
		this.locality = locality;
	}
	public double getDecimalLatitude() {
		return decimalLatitude;
	}
	public void setDecimalLatitude(double decimalLatitude) {
		this.decimalLatitude = decimalLatitude;
	}
	public double getDecimalLongitude() {
		return decimalLongitude;
	}
	public void setDecimalLongitude(double decimalLongitude) {
		this.decimalLongitude = decimalLongitude;
	}
	public String getCoordinateUncertaintyInMeters() {
		return coordinateUncertaintyInMeters;
	}
	public void setCoordinateUncertaintyInMeters(String coordinateUncertaintyInMeters) {
		this.coordinateUncertaintyInMeters = coordinateUncertaintyInMeters;
	}
	public BasisOfRecord getBasisOfRecord() {
		return basisOfRecord;
	}
	public void setBasisOfRecord(BasisOfRecord basisOfRecord) {
		this.basisOfRecord = basisOfRecord;
	}
	public double getMaxDepth() {
		return maxDepth;
	}
	public void setMaxDepth(double maxDepth) {
		this.maxDepth = maxDepth;
	}
	public double getMinDepth() {
		return minDepth;
	}
	public void setMinDepth(double minDepth) {
		this.minDepth = minDepth;
	}
	
	public Calendar getModified() {
		return modified;
	}
	public void setModified(Calendar modified) {
		this.modified = modified;
	}
	
	public String getCatalogueNumber() {
		return catalogueNumber;
	}
	public void setCatalogueNumber(String catalogueNumber) {
		this.catalogueNumber = catalogueNumber;
	}
	
	public DataSet getDataSet() {
		return dataSet;
	}
	public void setDataSet(DataSet dataSet) {
		this.dataSet = dataSet;
	}
	
	
	
	public String getProvider() {
		return provider;
	}

	public void setProvider(String provider) {
		this.provider = provider;
	}

	public ResultType getType() {
		return ResultType.OCCURRENCEPOINT;
	}

	
	
	public String getAuthor() {
		return author;
	}

	public void setAuthor(String author) {
		this.author = author;
	}

	public String getCredits() {
		return credits;
	}

	public void setCredits(String credits) {
		this.credits = credits;
	}

	public void addProperty(ElementProperty property){
		this.properties.add(property);
	}
	
	public void resetProperties(){
		this.properties = new ArrayList<ElementProperty>();
	}
	
	
	public List<ElementProperty> getProperties() {
		return Collections.unmodifiableList(properties);
	}

	@Override
	public String toString() {
		return "OccurrencePoint [id=" + id + ", institutionCode="
				+ institutionCode + ", collectionCode=" + collectionCode
				+ ", catalogueNumber=" + catalogueNumber + ", recordedBy="
				+ recordedBy + ", eventDate=" + eventDate + ", modified="
				+ modified + ", scientificName=" + scientificName
				+ ", kingdom=" + kingdom + ", family=" + family + ", locality="
				+ locality + ", country=" + country + ", citation=" + citation
				+ ", decimalLatitude=" + decimalLatitude
				+ ", decimalLongitude=" + decimalLongitude
				+ ", coordinateUncertaintyInMeters="
				+ coordinateUncertaintyInMeters + ", maxDepth=" + maxDepth
				+ ", minDepth=" + minDepth + ", basisOfRecord=" + basisOfRecord
				+ ", dataSet=" + dataSet + "]";
	}

	
}
